# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: python_pachyderm/proto/v2/pfs/pfs.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from python_pachyderm.proto.v2.auth import auth_pb2 as python__pachyderm_dot_proto_dot_v2_dot_auth_dot_auth__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='python_pachyderm/proto/v2/pfs/pfs.proto',
  package='pfs_v2',
  syntax='proto3',
  serialized_options=b'Z)github.com/pachyderm/pachyderm/v2/src/pfs',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\'python_pachyderm/proto/v2/pfs/pfs.proto\x12\x06pfs_v2\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a)python_pachyderm/proto/v2/auth/auth.proto\"\"\n\x04Repo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\"2\n\x06\x42ranch\x12\x1a\n\x04repo\x18\x01 \x01(\x0b\x32\x0c.pfs_v2.Repo\x12\x0c\n\x04name\x18\x02 \x01(\t\"C\n\x04\x46ile\x12\x1e\n\x06\x63ommit\x18\x01 \x01(\x0b\x32\x0e.pfs_v2.Commit\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\r\n\x05\x64\x61tum\x18\x03 \x01(\t\"\x9d\x02\n\x08RepoInfo\x12\x1a\n\x04repo\x18\x01 \x01(\x0b\x32\x0c.pfs_v2.Repo\x12+\n\x07\x63reated\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1e\n\x16size_bytes_upper_bound\x18\x03 \x01(\x03\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12 \n\x08\x62ranches\x18\x05 \x03(\x0b\x32\x0e.pfs_v2.Branch\x12\'\n\tauth_info\x18\x06 \x01(\x0b\x32\x14.pfs_v2.RepoAuthInfo\x12)\n\x07\x64\x65tails\x18\x07 \x01(\x0b\x32\x18.pfs_v2.RepoInfo.Details\x1a\x1d\n\x07\x44\x65tails\x12\x12\n\nsize_bytes\x18\x01 \x01(\x03\"G\n\x0cRepoAuthInfo\x12(\n\x0bpermissions\x18\x01 \x03(\x0e\x32\x13.auth_v2.Permission\x12\r\n\x05roles\x18\x02 \x03(\t\"\xdf\x01\n\nBranchInfo\x12\x1e\n\x06\x62ranch\x18\x01 \x01(\x0b\x32\x0e.pfs_v2.Branch\x12\x1c\n\x04head\x18\x02 \x01(\x0b\x32\x0e.pfs_v2.Commit\x12\"\n\nprovenance\x18\x03 \x03(\x0b\x32\x0e.pfs_v2.Branch\x12\"\n\nsubvenance\x18\x04 \x03(\x0b\x32\x0e.pfs_v2.Branch\x12)\n\x11\x64irect_provenance\x18\x05 \x03(\x0b\x32\x0e.pfs_v2.Branch\x12 \n\x07trigger\x18\x06 \x01(\x0b\x32\x0f.pfs_v2.Trigger\"X\n\x07Trigger\x12\x0e\n\x06\x62ranch\x18\x01 \x01(\t\x12\x0b\n\x03\x61ll\x18\x02 \x01(\x08\x12\x11\n\tcron_spec\x18\x03 \x01(\t\x12\x0c\n\x04size\x18\x04 \x01(\t\x12\x0f\n\x07\x63ommits\x18\x05 \x01(\x03\"0\n\x0c\x43ommitOrigin\x12 \n\x04kind\x18\x01 \x01(\x0e\x32\x12.pfs_v2.OriginKind\"4\n\x06\x43ommit\x12\x1e\n\x06\x62ranch\x18\x01 \x01(\x0b\x32\x0e.pfs_v2.Branch\x12\n\n\x02id\x18\x02 \x01(\t\"\xe5\x03\n\nCommitInfo\x12\x1e\n\x06\x63ommit\x18\x01 \x01(\x0b\x32\x0e.pfs_v2.Commit\x12$\n\x06origin\x18\x02 \x01(\x0b\x32\x14.pfs_v2.CommitOrigin\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12%\n\rparent_commit\x18\x04 \x01(\x0b\x32\x0e.pfs_v2.Commit\x12%\n\rchild_commits\x18\x05 \x03(\x0b\x32\x0e.pfs_v2.Commit\x12+\n\x07started\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12-\n\tfinishing\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x66inished\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12)\n\x11\x64irect_provenance\x18\t \x03(\x0b\x32\x0e.pfs_v2.Branch\x12\r\n\x05\x65rror\x18\n \x01(\t\x12\x1e\n\x16size_bytes_upper_bound\x18\x0b \x01(\x03\x12+\n\x07\x64\x65tails\x18\x0c \x01(\x0b\x32\x1a.pfs_v2.CommitInfo.Details\x1a\x1d\n\x07\x44\x65tails\x12\x12\n\nsize_bytes\x18\x01 \x01(\x03\"\x17\n\tCommitSet\x12\n\n\x02id\x18\x01 \x01(\t\"[\n\rCommitSetInfo\x12%\n\ncommit_set\x18\x01 \x01(\x0b\x32\x11.pfs_v2.CommitSet\x12#\n\x07\x63ommits\x18\x02 \x03(\x0b\x32\x12.pfs_v2.CommitInfo\"\x9c\x01\n\x08\x46ileInfo\x12\x1a\n\x04\x66ile\x18\x01 \x01(\x0b\x32\x0c.pfs_v2.File\x12#\n\tfile_type\x18\x02 \x01(\x0e\x32\x10.pfs_v2.FileType\x12-\n\tcommitted\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nsize_bytes\x18\x04 \x01(\x03\x12\x0c\n\x04hash\x18\x05 \x01(\x0c\"T\n\x11\x43reateRepoRequest\x12\x1a\n\x04repo\x18\x01 \x01(\x0b\x32\x0c.pfs_v2.Repo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\x08\"0\n\x12InspectRepoRequest\x12\x1a\n\x04repo\x18\x01 \x01(\x0b\x32\x0c.pfs_v2.Repo\"\x1f\n\x0fListRepoRequest\x12\x0c\n\x04type\x18\x01 \x01(\t\">\n\x11\x44\x65leteRepoRequest\x12\x1a\n\x04repo\x18\x01 \x01(\x0b\x32\x0c.pfs_v2.Repo\x12\r\n\x05\x66orce\x18\x02 \x01(\x08\"i\n\x12StartCommitRequest\x12\x1e\n\x06parent\x18\x01 \x01(\x0b\x32\x0e.pfs_v2.Commit\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x1e\n\x06\x62ranch\x18\x03 \x01(\x0b\x32\x0e.pfs_v2.Branch\"h\n\x13\x46inishCommitRequest\x12\x1e\n\x06\x63ommit\x18\x01 \x01(\x0b\x32\x0e.pfs_v2.Commit\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\r\n\x05\x65rror\x18\x03 \x01(\t\x12\r\n\x05\x66orce\x18\x04 \x01(\x08\"Y\n\x14InspectCommitRequest\x12\x1e\n\x06\x63ommit\x18\x01 \x01(\x0b\x32\x0e.pfs_v2.Commit\x12!\n\x04wait\x18\x02 \x01(\x0e\x32\x13.pfs_v2.CommitState\"\xc0\x01\n\x11ListCommitRequest\x12\x1a\n\x04repo\x18\x01 \x01(\x0b\x32\x0c.pfs_v2.Repo\x12\x1c\n\x04\x66rom\x18\x02 \x01(\x0b\x32\x0e.pfs_v2.Commit\x12\x1a\n\x02to\x18\x03 \x01(\x0b\x32\x0e.pfs_v2.Commit\x12\x0e\n\x06number\x18\x04 \x01(\x03\x12\x0f\n\x07reverse\x18\x05 \x01(\x08\x12\x0b\n\x03\x61ll\x18\x06 \x01(\x08\x12\'\n\x0borigin_kind\x18\x07 \x01(\x0e\x32\x12.pfs_v2.OriginKind\"N\n\x17InspectCommitSetRequest\x12%\n\ncommit_set\x18\x01 \x01(\x0b\x32\x11.pfs_v2.CommitSet\x12\x0c\n\x04wait\x18\x02 \x01(\x08\"\x16\n\x14ListCommitSetRequest\"?\n\x16SquashCommitSetRequest\x12%\n\ncommit_set\x18\x01 \x01(\x0b\x32\x11.pfs_v2.CommitSet\"=\n\x14\x44ropCommitSetRequest\x12%\n\ncommit_set\x18\x01 \x01(\x0b\x32\x11.pfs_v2.CommitSet\"\xbc\x01\n\x16SubscribeCommitRequest\x12\x1a\n\x04repo\x18\x01 \x01(\x0b\x32\x0c.pfs_v2.Repo\x12\x0e\n\x06\x62ranch\x18\x02 \x01(\t\x12\x1c\n\x04\x66rom\x18\x03 \x01(\x0b\x32\x0e.pfs_v2.Commit\x12\"\n\x05state\x18\x04 \x01(\x0e\x32\x13.pfs_v2.CommitState\x12\x0b\n\x03\x61ll\x18\x05 \x01(\x08\x12\'\n\x0borigin_kind\x18\x06 \x01(\x0e\x32\x12.pfs_v2.OriginKind\"4\n\x12\x43learCommitRequest\x12\x1e\n\x06\x63ommit\x18\x01 \x01(\x0b\x32\x0e.pfs_v2.Commit\"\xb1\x01\n\x13\x43reateBranchRequest\x12\x1c\n\x04head\x18\x01 \x01(\x0b\x32\x0e.pfs_v2.Commit\x12\x1e\n\x06\x62ranch\x18\x02 \x01(\x0b\x32\x0e.pfs_v2.Branch\x12\"\n\nprovenance\x18\x03 \x03(\x0b\x32\x0e.pfs_v2.Branch\x12 \n\x07trigger\x18\x04 \x01(\x0b\x32\x0f.pfs_v2.Trigger\x12\x16\n\x0enew_commit_set\x18\x05 \x01(\x08\"6\n\x14InspectBranchRequest\x12\x1e\n\x06\x62ranch\x18\x01 \x01(\x0b\x32\x0e.pfs_v2.Branch\"@\n\x11ListBranchRequest\x12\x1a\n\x04repo\x18\x01 \x01(\x0b\x32\x0c.pfs_v2.Repo\x12\x0f\n\x07reverse\x18\x02 \x01(\x08\"D\n\x13\x44\x65leteBranchRequest\x12\x1e\n\x06\x62ranch\x18\x01 \x01(\x0b\x32\x0e.pfs_v2.Branch\x12\r\n\x05\x66orce\x18\x02 \x01(\x08\"\xb3\x01\n\x07\x41\x64\x64\x46ile\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\r\n\x05\x64\x61tum\x18\x02 \x01(\t\x12*\n\x03raw\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.BytesValueH\x00\x12(\n\x03url\x18\x04 \x01(\x0b\x32\x19.pfs_v2.AddFile.URLSourceH\x00\x1a+\n\tURLSource\x12\x0b\n\x03URL\x18\x01 \x01(\t\x12\x11\n\trecursive\x18\x02 \x01(\x08\x42\x08\n\x06source\")\n\nDeleteFile\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\r\n\x05\x64\x61tum\x18\x02 \x01(\t\"Q\n\x08\x43opyFile\x12\x0b\n\x03\x64st\x18\x01 \x01(\t\x12\r\n\x05\x64\x61tum\x18\x02 \x01(\t\x12\x19\n\x03src\x18\x03 \x01(\x0b\x32\x0c.pfs_v2.File\x12\x0e\n\x06\x61ppend\x18\x04 \x01(\x08\"\xb8\x01\n\x11ModifyFileRequest\x12$\n\nset_commit\x18\x01 \x01(\x0b\x32\x0e.pfs_v2.CommitH\x00\x12#\n\x08\x61\x64\x64_file\x18\x02 \x01(\x0b\x32\x0f.pfs_v2.AddFileH\x00\x12)\n\x0b\x64\x65lete_file\x18\x03 \x01(\x0b\x32\x12.pfs_v2.DeleteFileH\x00\x12%\n\tcopy_file\x18\x04 \x01(\x0b\x32\x10.pfs_v2.CopyFileH\x00\x42\x06\n\x04\x62ody\"I\n\x0eGetFileRequest\x12\x1a\n\x04\x66ile\x18\x01 \x01(\x0b\x32\x0c.pfs_v2.File\x12\x0b\n\x03URL\x18\x02 \x01(\t\x12\x0e\n\x06offset\x18\x03 \x01(\x03\"0\n\x12InspectFileRequest\x12\x1a\n\x04\x66ile\x18\x01 \x01(\x0b\x32\x0c.pfs_v2.File\">\n\x0fListFileRequest\x12\x1a\n\x04\x66ile\x18\x01 \x01(\x0b\x32\x0c.pfs_v2.File\x12\x0f\n\x07\x64\x65tails\x18\x02 \x01(\x08\"-\n\x0fWalkFileRequest\x12\x1a\n\x04\x66ile\x18\x01 \x01(\x0b\x32\x0c.pfs_v2.File\"B\n\x0fGlobFileRequest\x12\x1e\n\x06\x63ommit\x18\x01 \x01(\x0b\x32\x0e.pfs_v2.Commit\x12\x0f\n\x07pattern\x18\x02 \x01(\t\"b\n\x0f\x44iffFileRequest\x12\x1e\n\x08new_file\x18\x01 \x01(\x0b\x32\x0c.pfs_v2.File\x12\x1e\n\x08old_file\x18\x02 \x01(\x0b\x32\x0c.pfs_v2.File\x12\x0f\n\x07shallow\x18\x03 \x01(\x08\"Z\n\x10\x44iffFileResponse\x12\"\n\x08new_file\x18\x01 \x01(\x0b\x32\x10.pfs_v2.FileInfo\x12\"\n\x08old_file\x18\x02 \x01(\x0b\x32\x10.pfs_v2.FileInfo\"\x1a\n\x0b\x46sckRequest\x12\x0b\n\x03\x66ix\x18\x01 \x01(\x08\"*\n\x0c\x46sckResponse\x12\x0b\n\x03\x66ix\x18\x01 \x01(\t\x12\r\n\x05\x65rror\x18\x02 \x01(\t\",\n\x15\x43reateFileSetResponse\x12\x13\n\x0b\x66ile_set_id\x18\x01 \x01(\t\"3\n\x11GetFileSetRequest\x12\x1e\n\x06\x63ommit\x18\x01 \x01(\x0b\x32\x0e.pfs_v2.Commit\"H\n\x11\x41\x64\x64\x46ileSetRequest\x12\x1e\n\x06\x63ommit\x18\x01 \x01(\x0b\x32\x0e.pfs_v2.Commit\x12\x13\n\x0b\x66ile_set_id\x18\x02 \x01(\t\"?\n\x13RenewFileSetRequest\x12\x13\n\x0b\x66ile_set_id\x18\x01 \x01(\t\x12\x13\n\x0bttl_seconds\x18\x02 \x01(\x03\"\x15\n\x13\x41\x63tivateAuthRequest\"\x16\n\x14\x41\x63tivateAuthResponse\"P\n\x12RunLoadTestRequest\x12\x0c\n\x04spec\x18\x01 \x01(\t\x12\x1e\n\x06\x62ranch\x18\x02 \x01(\x0b\x32\x0e.pfs_v2.Branch\x12\x0c\n\x04seed\x18\x03 \x01(\x03\"`\n\x13RunLoadTestResponse\x12\x0c\n\x04spec\x18\x01 \x01(\t\x12\x1e\n\x06\x62ranch\x18\x02 \x01(\x0b\x32\x0e.pfs_v2.Branch\x12\x0c\n\x04seed\x18\x03 \x01(\x03\x12\r\n\x05\x65rror\x18\x04 \x01(\t*N\n\nOriginKind\x12\x17\n\x13ORIGIN_KIND_UNKNOWN\x10\x00\x12\x08\n\x04USER\x10\x01\x12\x08\n\x04\x41UTO\x10\x02\x12\x08\n\x04\x46SCK\x10\x03\x12\t\n\x05\x41LIAS\x10\x04*+\n\x08\x46ileType\x12\x0c\n\x08RESERVED\x10\x00\x12\x08\n\x04\x46ILE\x10\x01\x12\x07\n\x03\x44IR\x10\x02*\\\n\x0b\x43ommitState\x12\x18\n\x14\x43OMMIT_STATE_UNKNOWN\x10\x00\x12\x0b\n\x07STARTED\x10\x01\x12\t\n\x05READY\x10\x02\x12\r\n\tFINISHING\x10\x03\x12\x0c\n\x08\x46INISHED\x10\x04*;\n\tDelimiter\x12\x08\n\x04NONE\x10\x00\x12\x08\n\x04JSON\x10\x01\x12\x08\n\x04LINE\x10\x02\x12\x07\n\x03SQL\x10\x03\x12\x07\n\x03\x43SV\x10\x04\x32\xe0\x12\n\x03\x41PI\x12\x41\n\nCreateRepo\x12\x19.pfs_v2.CreateRepoRequest\x1a\x16.google.protobuf.Empty\"\x00\x12=\n\x0bInspectRepo\x12\x1a.pfs_v2.InspectRepoRequest\x1a\x10.pfs_v2.RepoInfo\"\x00\x12\x39\n\x08ListRepo\x12\x17.pfs_v2.ListRepoRequest\x1a\x10.pfs_v2.RepoInfo\"\x00\x30\x01\x12\x41\n\nDeleteRepo\x12\x19.pfs_v2.DeleteRepoRequest\x1a\x16.google.protobuf.Empty\"\x00\x12;\n\x0bStartCommit\x12\x1a.pfs_v2.StartCommitRequest\x1a\x0e.pfs_v2.Commit\"\x00\x12\x45\n\x0c\x46inishCommit\x12\x1b.pfs_v2.FinishCommitRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\x43\n\x0b\x43learCommit\x12\x1a.pfs_v2.ClearCommitRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\x43\n\rInspectCommit\x12\x1c.pfs_v2.InspectCommitRequest\x1a\x12.pfs_v2.CommitInfo\"\x00\x12?\n\nListCommit\x12\x19.pfs_v2.ListCommitRequest\x1a\x12.pfs_v2.CommitInfo\"\x00\x30\x01\x12I\n\x0fSubscribeCommit\x12\x1e.pfs_v2.SubscribeCommitRequest\x1a\x12.pfs_v2.CommitInfo\"\x00\x30\x01\x12K\n\x10InspectCommitSet\x12\x1f.pfs_v2.InspectCommitSetRequest\x1a\x12.pfs_v2.CommitInfo\"\x00\x30\x01\x12H\n\rListCommitSet\x12\x1c.pfs_v2.ListCommitSetRequest\x1a\x15.pfs_v2.CommitSetInfo\"\x00\x30\x01\x12K\n\x0fSquashCommitSet\x12\x1e.pfs_v2.SquashCommitSetRequest\x1a\x16.google.protobuf.Empty\"\x00\x12G\n\rDropCommitSet\x12\x1c.pfs_v2.DropCommitSetRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\x45\n\x0c\x43reateBranch\x12\x1b.pfs_v2.CreateBranchRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\x43\n\rInspectBranch\x12\x1c.pfs_v2.InspectBranchRequest\x1a\x12.pfs_v2.BranchInfo\"\x00\x12?\n\nListBranch\x12\x19.pfs_v2.ListBranchRequest\x1a\x12.pfs_v2.BranchInfo\"\x00\x30\x01\x12\x45\n\x0c\x44\x65leteBranch\x12\x1b.pfs_v2.DeleteBranchRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\x43\n\nModifyFile\x12\x19.pfs_v2.ModifyFileRequest\x1a\x16.google.protobuf.Empty\"\x00(\x01\x12\x42\n\x07GetFile\x12\x16.pfs_v2.GetFileRequest\x1a\x1b.google.protobuf.BytesValue\"\x00\x30\x01\x12\x45\n\nGetFileTAR\x12\x16.pfs_v2.GetFileRequest\x1a\x1b.google.protobuf.BytesValue\"\x00\x30\x01\x12=\n\x0bInspectFile\x12\x1a.pfs_v2.InspectFileRequest\x1a\x10.pfs_v2.FileInfo\"\x00\x12\x39\n\x08ListFile\x12\x17.pfs_v2.ListFileRequest\x1a\x10.pfs_v2.FileInfo\"\x00\x30\x01\x12\x39\n\x08WalkFile\x12\x17.pfs_v2.WalkFileRequest\x1a\x10.pfs_v2.FileInfo\"\x00\x30\x01\x12\x39\n\x08GlobFile\x12\x17.pfs_v2.GlobFileRequest\x1a\x10.pfs_v2.FileInfo\"\x00\x30\x01\x12\x41\n\x08\x44iffFile\x12\x17.pfs_v2.DiffFileRequest\x1a\x18.pfs_v2.DiffFileResponse\"\x00\x30\x01\x12K\n\x0c\x41\x63tivateAuth\x12\x1b.pfs_v2.ActivateAuthRequest\x1a\x1c.pfs_v2.ActivateAuthResponse\"\x00\x12=\n\tDeleteAll\x12\x16.google.protobuf.Empty\x1a\x16.google.protobuf.Empty\"\x00\x12\x35\n\x04\x46sck\x12\x13.pfs_v2.FsckRequest\x1a\x14.pfs_v2.FsckResponse\"\x00\x30\x01\x12M\n\rCreateFileSet\x12\x19.pfs_v2.ModifyFileRequest\x1a\x1d.pfs_v2.CreateFileSetResponse\"\x00(\x01\x12H\n\nGetFileSet\x12\x19.pfs_v2.GetFileSetRequest\x1a\x1d.pfs_v2.CreateFileSetResponse\"\x00\x12\x41\n\nAddFileSet\x12\x19.pfs_v2.AddFileSetRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\x45\n\x0cRenewFileSet\x12\x1b.pfs_v2.RenewFileSetRequest\x1a\x16.google.protobuf.Empty\"\x00\x12H\n\x0bRunLoadTest\x12\x1a.pfs_v2.RunLoadTestRequest\x1a\x1b.pfs_v2.RunLoadTestResponse\"\x00\x12K\n\x12RunLoadTestDefault\x12\x16.google.protobuf.Empty\x1a\x1b.pfs_v2.RunLoadTestResponse\"\x00\x42+Z)github.com/pachyderm/pachyderm/v2/src/pfsb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,python__pachyderm_dot_proto_dot_v2_dot_auth_dot_auth__pb2.DESCRIPTOR,])

_ORIGINKIND = _descriptor.EnumDescriptor(
  name='OriginKind',
  full_name='pfs_v2.OriginKind',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ORIGIN_KIND_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='USER', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AUTO', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FSCK', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ALIAS', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5000,
  serialized_end=5078,
)
_sym_db.RegisterEnumDescriptor(_ORIGINKIND)

OriginKind = enum_type_wrapper.EnumTypeWrapper(_ORIGINKIND)
_FILETYPE = _descriptor.EnumDescriptor(
  name='FileType',
  full_name='pfs_v2.FileType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RESERVED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FILE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DIR', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5080,
  serialized_end=5123,
)
_sym_db.RegisterEnumDescriptor(_FILETYPE)

FileType = enum_type_wrapper.EnumTypeWrapper(_FILETYPE)
_COMMITSTATE = _descriptor.EnumDescriptor(
  name='CommitState',
  full_name='pfs_v2.CommitState',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='COMMIT_STATE_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STARTED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='READY', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FINISHING', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FINISHED', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5125,
  serialized_end=5217,
)
_sym_db.RegisterEnumDescriptor(_COMMITSTATE)

CommitState = enum_type_wrapper.EnumTypeWrapper(_COMMITSTATE)
_DELIMITER = _descriptor.EnumDescriptor(
  name='Delimiter',
  full_name='pfs_v2.Delimiter',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='JSON', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LINE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SQL', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CSV', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5219,
  serialized_end=5278,
)
_sym_db.RegisterEnumDescriptor(_DELIMITER)

Delimiter = enum_type_wrapper.EnumTypeWrapper(_DELIMITER)
ORIGIN_KIND_UNKNOWN = 0
USER = 1
AUTO = 2
FSCK = 3
ALIAS = 4
RESERVED = 0
FILE = 1
DIR = 2
COMMIT_STATE_UNKNOWN = 0
STARTED = 1
READY = 2
FINISHING = 3
FINISHED = 4
NONE = 0
JSON = 1
LINE = 2
SQL = 3
CSV = 4



_REPO = _descriptor.Descriptor(
  name='Repo',
  full_name='pfs_v2.Repo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='pfs_v2.Repo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='pfs_v2.Repo.type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=188,
  serialized_end=222,
)


_BRANCH = _descriptor.Descriptor(
  name='Branch',
  full_name='pfs_v2.Branch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='repo', full_name='pfs_v2.Branch.repo', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='pfs_v2.Branch.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=224,
  serialized_end=274,
)


_FILE = _descriptor.Descriptor(
  name='File',
  full_name='pfs_v2.File',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='commit', full_name='pfs_v2.File.commit', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='pfs_v2.File.path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='datum', full_name='pfs_v2.File.datum', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=276,
  serialized_end=343,
)


_REPOINFO_DETAILS = _descriptor.Descriptor(
  name='Details',
  full_name='pfs_v2.RepoInfo.Details',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='size_bytes', full_name='pfs_v2.RepoInfo.Details.size_bytes', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=602,
  serialized_end=631,
)

_REPOINFO = _descriptor.Descriptor(
  name='RepoInfo',
  full_name='pfs_v2.RepoInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='repo', full_name='pfs_v2.RepoInfo.repo', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created', full_name='pfs_v2.RepoInfo.created', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size_bytes_upper_bound', full_name='pfs_v2.RepoInfo.size_bytes_upper_bound', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='pfs_v2.RepoInfo.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='branches', full_name='pfs_v2.RepoInfo.branches', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auth_info', full_name='pfs_v2.RepoInfo.auth_info', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='details', full_name='pfs_v2.RepoInfo.details', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_REPOINFO_DETAILS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=346,
  serialized_end=631,
)


_REPOAUTHINFO = _descriptor.Descriptor(
  name='RepoAuthInfo',
  full_name='pfs_v2.RepoAuthInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='permissions', full_name='pfs_v2.RepoAuthInfo.permissions', index=0,
      number=1, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='roles', full_name='pfs_v2.RepoAuthInfo.roles', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=633,
  serialized_end=704,
)


_BRANCHINFO = _descriptor.Descriptor(
  name='BranchInfo',
  full_name='pfs_v2.BranchInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='branch', full_name='pfs_v2.BranchInfo.branch', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='head', full_name='pfs_v2.BranchInfo.head', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='provenance', full_name='pfs_v2.BranchInfo.provenance', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subvenance', full_name='pfs_v2.BranchInfo.subvenance', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='direct_provenance', full_name='pfs_v2.BranchInfo.direct_provenance', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trigger', full_name='pfs_v2.BranchInfo.trigger', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=707,
  serialized_end=930,
)


_TRIGGER = _descriptor.Descriptor(
  name='Trigger',
  full_name='pfs_v2.Trigger',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='branch', full_name='pfs_v2.Trigger.branch', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='all', full_name='pfs_v2.Trigger.all', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cron_spec', full_name='pfs_v2.Trigger.cron_spec', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='pfs_v2.Trigger.size', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commits', full_name='pfs_v2.Trigger.commits', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=932,
  serialized_end=1020,
)


_COMMITORIGIN = _descriptor.Descriptor(
  name='CommitOrigin',
  full_name='pfs_v2.CommitOrigin',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='kind', full_name='pfs_v2.CommitOrigin.kind', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1022,
  serialized_end=1070,
)


_COMMIT = _descriptor.Descriptor(
  name='Commit',
  full_name='pfs_v2.Commit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='branch', full_name='pfs_v2.Commit.branch', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='pfs_v2.Commit.id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1072,
  serialized_end=1124,
)


_COMMITINFO_DETAILS = _descriptor.Descriptor(
  name='Details',
  full_name='pfs_v2.CommitInfo.Details',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='size_bytes', full_name='pfs_v2.CommitInfo.Details.size_bytes', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=602,
  serialized_end=631,
)

_COMMITINFO = _descriptor.Descriptor(
  name='CommitInfo',
  full_name='pfs_v2.CommitInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='commit', full_name='pfs_v2.CommitInfo.commit', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='origin', full_name='pfs_v2.CommitInfo.origin', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='pfs_v2.CommitInfo.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parent_commit', full_name='pfs_v2.CommitInfo.parent_commit', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='child_commits', full_name='pfs_v2.CommitInfo.child_commits', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='started', full_name='pfs_v2.CommitInfo.started', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='finishing', full_name='pfs_v2.CommitInfo.finishing', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='finished', full_name='pfs_v2.CommitInfo.finished', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='direct_provenance', full_name='pfs_v2.CommitInfo.direct_provenance', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error', full_name='pfs_v2.CommitInfo.error', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size_bytes_upper_bound', full_name='pfs_v2.CommitInfo.size_bytes_upper_bound', index=10,
      number=11, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='details', full_name='pfs_v2.CommitInfo.details', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_COMMITINFO_DETAILS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1127,
  serialized_end=1612,
)


_COMMITSET = _descriptor.Descriptor(
  name='CommitSet',
  full_name='pfs_v2.CommitSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='pfs_v2.CommitSet.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1614,
  serialized_end=1637,
)


_COMMITSETINFO = _descriptor.Descriptor(
  name='CommitSetInfo',
  full_name='pfs_v2.CommitSetInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='commit_set', full_name='pfs_v2.CommitSetInfo.commit_set', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commits', full_name='pfs_v2.CommitSetInfo.commits', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1639,
  serialized_end=1730,
)


_FILEINFO = _descriptor.Descriptor(
  name='FileInfo',
  full_name='pfs_v2.FileInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='file', full_name='pfs_v2.FileInfo.file', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_type', full_name='pfs_v2.FileInfo.file_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='committed', full_name='pfs_v2.FileInfo.committed', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size_bytes', full_name='pfs_v2.FileInfo.size_bytes', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hash', full_name='pfs_v2.FileInfo.hash', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1733,
  serialized_end=1889,
)


_CREATEREPOREQUEST = _descriptor.Descriptor(
  name='CreateRepoRequest',
  full_name='pfs_v2.CreateRepoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='repo', full_name='pfs_v2.CreateRepoRequest.repo', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='pfs_v2.CreateRepoRequest.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update', full_name='pfs_v2.CreateRepoRequest.update', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1891,
  serialized_end=1975,
)


_INSPECTREPOREQUEST = _descriptor.Descriptor(
  name='InspectRepoRequest',
  full_name='pfs_v2.InspectRepoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='repo', full_name='pfs_v2.InspectRepoRequest.repo', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1977,
  serialized_end=2025,
)


_LISTREPOREQUEST = _descriptor.Descriptor(
  name='ListRepoRequest',
  full_name='pfs_v2.ListRepoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='pfs_v2.ListRepoRequest.type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2027,
  serialized_end=2058,
)


_DELETEREPOREQUEST = _descriptor.Descriptor(
  name='DeleteRepoRequest',
  full_name='pfs_v2.DeleteRepoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='repo', full_name='pfs_v2.DeleteRepoRequest.repo', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='force', full_name='pfs_v2.DeleteRepoRequest.force', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2060,
  serialized_end=2122,
)


_STARTCOMMITREQUEST = _descriptor.Descriptor(
  name='StartCommitRequest',
  full_name='pfs_v2.StartCommitRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent', full_name='pfs_v2.StartCommitRequest.parent', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='pfs_v2.StartCommitRequest.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='branch', full_name='pfs_v2.StartCommitRequest.branch', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2124,
  serialized_end=2229,
)


_FINISHCOMMITREQUEST = _descriptor.Descriptor(
  name='FinishCommitRequest',
  full_name='pfs_v2.FinishCommitRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='commit', full_name='pfs_v2.FinishCommitRequest.commit', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='pfs_v2.FinishCommitRequest.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error', full_name='pfs_v2.FinishCommitRequest.error', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='force', full_name='pfs_v2.FinishCommitRequest.force', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2231,
  serialized_end=2335,
)


_INSPECTCOMMITREQUEST = _descriptor.Descriptor(
  name='InspectCommitRequest',
  full_name='pfs_v2.InspectCommitRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='commit', full_name='pfs_v2.InspectCommitRequest.commit', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wait', full_name='pfs_v2.InspectCommitRequest.wait', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2337,
  serialized_end=2426,
)


_LISTCOMMITREQUEST = _descriptor.Descriptor(
  name='ListCommitRequest',
  full_name='pfs_v2.ListCommitRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='repo', full_name='pfs_v2.ListCommitRequest.repo', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='from', full_name='pfs_v2.ListCommitRequest.from', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='to', full_name='pfs_v2.ListCommitRequest.to', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='number', full_name='pfs_v2.ListCommitRequest.number', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reverse', full_name='pfs_v2.ListCommitRequest.reverse', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='all', full_name='pfs_v2.ListCommitRequest.all', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='origin_kind', full_name='pfs_v2.ListCommitRequest.origin_kind', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2429,
  serialized_end=2621,
)


_INSPECTCOMMITSETREQUEST = _descriptor.Descriptor(
  name='InspectCommitSetRequest',
  full_name='pfs_v2.InspectCommitSetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='commit_set', full_name='pfs_v2.InspectCommitSetRequest.commit_set', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wait', full_name='pfs_v2.InspectCommitSetRequest.wait', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2623,
  serialized_end=2701,
)


_LISTCOMMITSETREQUEST = _descriptor.Descriptor(
  name='ListCommitSetRequest',
  full_name='pfs_v2.ListCommitSetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2703,
  serialized_end=2725,
)


_SQUASHCOMMITSETREQUEST = _descriptor.Descriptor(
  name='SquashCommitSetRequest',
  full_name='pfs_v2.SquashCommitSetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='commit_set', full_name='pfs_v2.SquashCommitSetRequest.commit_set', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2727,
  serialized_end=2790,
)


_DROPCOMMITSETREQUEST = _descriptor.Descriptor(
  name='DropCommitSetRequest',
  full_name='pfs_v2.DropCommitSetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='commit_set', full_name='pfs_v2.DropCommitSetRequest.commit_set', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2792,
  serialized_end=2853,
)


_SUBSCRIBECOMMITREQUEST = _descriptor.Descriptor(
  name='SubscribeCommitRequest',
  full_name='pfs_v2.SubscribeCommitRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='repo', full_name='pfs_v2.SubscribeCommitRequest.repo', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='branch', full_name='pfs_v2.SubscribeCommitRequest.branch', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='from', full_name='pfs_v2.SubscribeCommitRequest.from', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='pfs_v2.SubscribeCommitRequest.state', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='all', full_name='pfs_v2.SubscribeCommitRequest.all', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='origin_kind', full_name='pfs_v2.SubscribeCommitRequest.origin_kind', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2856,
  serialized_end=3044,
)


_CLEARCOMMITREQUEST = _descriptor.Descriptor(
  name='ClearCommitRequest',
  full_name='pfs_v2.ClearCommitRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='commit', full_name='pfs_v2.ClearCommitRequest.commit', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3046,
  serialized_end=3098,
)


_CREATEBRANCHREQUEST = _descriptor.Descriptor(
  name='CreateBranchRequest',
  full_name='pfs_v2.CreateBranchRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='head', full_name='pfs_v2.CreateBranchRequest.head', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='branch', full_name='pfs_v2.CreateBranchRequest.branch', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='provenance', full_name='pfs_v2.CreateBranchRequest.provenance', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trigger', full_name='pfs_v2.CreateBranchRequest.trigger', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new_commit_set', full_name='pfs_v2.CreateBranchRequest.new_commit_set', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3101,
  serialized_end=3278,
)


_INSPECTBRANCHREQUEST = _descriptor.Descriptor(
  name='InspectBranchRequest',
  full_name='pfs_v2.InspectBranchRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='branch', full_name='pfs_v2.InspectBranchRequest.branch', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3280,
  serialized_end=3334,
)


_LISTBRANCHREQUEST = _descriptor.Descriptor(
  name='ListBranchRequest',
  full_name='pfs_v2.ListBranchRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='repo', full_name='pfs_v2.ListBranchRequest.repo', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reverse', full_name='pfs_v2.ListBranchRequest.reverse', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3336,
  serialized_end=3400,
)


_DELETEBRANCHREQUEST = _descriptor.Descriptor(
  name='DeleteBranchRequest',
  full_name='pfs_v2.DeleteBranchRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='branch', full_name='pfs_v2.DeleteBranchRequest.branch', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='force', full_name='pfs_v2.DeleteBranchRequest.force', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3402,
  serialized_end=3470,
)


_ADDFILE_URLSOURCE = _descriptor.Descriptor(
  name='URLSource',
  full_name='pfs_v2.AddFile.URLSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='URL', full_name='pfs_v2.AddFile.URLSource.URL', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='recursive', full_name='pfs_v2.AddFile.URLSource.recursive', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3599,
  serialized_end=3642,
)

_ADDFILE = _descriptor.Descriptor(
  name='AddFile',
  full_name='pfs_v2.AddFile',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='pfs_v2.AddFile.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='datum', full_name='pfs_v2.AddFile.datum', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='raw', full_name='pfs_v2.AddFile.raw', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='url', full_name='pfs_v2.AddFile.url', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ADDFILE_URLSOURCE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='source', full_name='pfs_v2.AddFile.source',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=3473,
  serialized_end=3652,
)


_DELETEFILE = _descriptor.Descriptor(
  name='DeleteFile',
  full_name='pfs_v2.DeleteFile',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='pfs_v2.DeleteFile.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='datum', full_name='pfs_v2.DeleteFile.datum', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3654,
  serialized_end=3695,
)


_COPYFILE = _descriptor.Descriptor(
  name='CopyFile',
  full_name='pfs_v2.CopyFile',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dst', full_name='pfs_v2.CopyFile.dst', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='datum', full_name='pfs_v2.CopyFile.datum', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='src', full_name='pfs_v2.CopyFile.src', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='append', full_name='pfs_v2.CopyFile.append', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3697,
  serialized_end=3778,
)


_MODIFYFILEREQUEST = _descriptor.Descriptor(
  name='ModifyFileRequest',
  full_name='pfs_v2.ModifyFileRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='set_commit', full_name='pfs_v2.ModifyFileRequest.set_commit', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='add_file', full_name='pfs_v2.ModifyFileRequest.add_file', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delete_file', full_name='pfs_v2.ModifyFileRequest.delete_file', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='copy_file', full_name='pfs_v2.ModifyFileRequest.copy_file', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='body', full_name='pfs_v2.ModifyFileRequest.body',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=3781,
  serialized_end=3965,
)


_GETFILEREQUEST = _descriptor.Descriptor(
  name='GetFileRequest',
  full_name='pfs_v2.GetFileRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='file', full_name='pfs_v2.GetFileRequest.file', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='URL', full_name='pfs_v2.GetFileRequest.URL', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offset', full_name='pfs_v2.GetFileRequest.offset', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3967,
  serialized_end=4040,
)


_INSPECTFILEREQUEST = _descriptor.Descriptor(
  name='InspectFileRequest',
  full_name='pfs_v2.InspectFileRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='file', full_name='pfs_v2.InspectFileRequest.file', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4042,
  serialized_end=4090,
)


_LISTFILEREQUEST = _descriptor.Descriptor(
  name='ListFileRequest',
  full_name='pfs_v2.ListFileRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='file', full_name='pfs_v2.ListFileRequest.file', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='details', full_name='pfs_v2.ListFileRequest.details', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4092,
  serialized_end=4154,
)


_WALKFILEREQUEST = _descriptor.Descriptor(
  name='WalkFileRequest',
  full_name='pfs_v2.WalkFileRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='file', full_name='pfs_v2.WalkFileRequest.file', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4156,
  serialized_end=4201,
)


_GLOBFILEREQUEST = _descriptor.Descriptor(
  name='GlobFileRequest',
  full_name='pfs_v2.GlobFileRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='commit', full_name='pfs_v2.GlobFileRequest.commit', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pattern', full_name='pfs_v2.GlobFileRequest.pattern', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4203,
  serialized_end=4269,
)


_DIFFFILEREQUEST = _descriptor.Descriptor(
  name='DiffFileRequest',
  full_name='pfs_v2.DiffFileRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='new_file', full_name='pfs_v2.DiffFileRequest.new_file', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='old_file', full_name='pfs_v2.DiffFileRequest.old_file', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shallow', full_name='pfs_v2.DiffFileRequest.shallow', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4271,
  serialized_end=4369,
)


_DIFFFILERESPONSE = _descriptor.Descriptor(
  name='DiffFileResponse',
  full_name='pfs_v2.DiffFileResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='new_file', full_name='pfs_v2.DiffFileResponse.new_file', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='old_file', full_name='pfs_v2.DiffFileResponse.old_file', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4371,
  serialized_end=4461,
)


_FSCKREQUEST = _descriptor.Descriptor(
  name='FsckRequest',
  full_name='pfs_v2.FsckRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fix', full_name='pfs_v2.FsckRequest.fix', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4463,
  serialized_end=4489,
)


_FSCKRESPONSE = _descriptor.Descriptor(
  name='FsckResponse',
  full_name='pfs_v2.FsckResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fix', full_name='pfs_v2.FsckResponse.fix', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error', full_name='pfs_v2.FsckResponse.error', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4491,
  serialized_end=4533,
)


_CREATEFILESETRESPONSE = _descriptor.Descriptor(
  name='CreateFileSetResponse',
  full_name='pfs_v2.CreateFileSetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='file_set_id', full_name='pfs_v2.CreateFileSetResponse.file_set_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4535,
  serialized_end=4579,
)


_GETFILESETREQUEST = _descriptor.Descriptor(
  name='GetFileSetRequest',
  full_name='pfs_v2.GetFileSetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='commit', full_name='pfs_v2.GetFileSetRequest.commit', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4581,
  serialized_end=4632,
)


_ADDFILESETREQUEST = _descriptor.Descriptor(
  name='AddFileSetRequest',
  full_name='pfs_v2.AddFileSetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='commit', full_name='pfs_v2.AddFileSetRequest.commit', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_set_id', full_name='pfs_v2.AddFileSetRequest.file_set_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4634,
  serialized_end=4706,
)


_RENEWFILESETREQUEST = _descriptor.Descriptor(
  name='RenewFileSetRequest',
  full_name='pfs_v2.RenewFileSetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='file_set_id', full_name='pfs_v2.RenewFileSetRequest.file_set_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ttl_seconds', full_name='pfs_v2.RenewFileSetRequest.ttl_seconds', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4708,
  serialized_end=4771,
)


_ACTIVATEAUTHREQUEST = _descriptor.Descriptor(
  name='ActivateAuthRequest',
  full_name='pfs_v2.ActivateAuthRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4773,
  serialized_end=4794,
)


_ACTIVATEAUTHRESPONSE = _descriptor.Descriptor(
  name='ActivateAuthResponse',
  full_name='pfs_v2.ActivateAuthResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4796,
  serialized_end=4818,
)


_RUNLOADTESTREQUEST = _descriptor.Descriptor(
  name='RunLoadTestRequest',
  full_name='pfs_v2.RunLoadTestRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='spec', full_name='pfs_v2.RunLoadTestRequest.spec', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='branch', full_name='pfs_v2.RunLoadTestRequest.branch', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='seed', full_name='pfs_v2.RunLoadTestRequest.seed', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4820,
  serialized_end=4900,
)


_RUNLOADTESTRESPONSE = _descriptor.Descriptor(
  name='RunLoadTestResponse',
  full_name='pfs_v2.RunLoadTestResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='spec', full_name='pfs_v2.RunLoadTestResponse.spec', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='branch', full_name='pfs_v2.RunLoadTestResponse.branch', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='seed', full_name='pfs_v2.RunLoadTestResponse.seed', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error', full_name='pfs_v2.RunLoadTestResponse.error', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4902,
  serialized_end=4998,
)

_BRANCH.fields_by_name['repo'].message_type = _REPO
_FILE.fields_by_name['commit'].message_type = _COMMIT
_REPOINFO_DETAILS.containing_type = _REPOINFO
_REPOINFO.fields_by_name['repo'].message_type = _REPO
_REPOINFO.fields_by_name['created'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_REPOINFO.fields_by_name['branches'].message_type = _BRANCH
_REPOINFO.fields_by_name['auth_info'].message_type = _REPOAUTHINFO
_REPOINFO.fields_by_name['details'].message_type = _REPOINFO_DETAILS
_REPOAUTHINFO.fields_by_name['permissions'].enum_type = python__pachyderm_dot_proto_dot_v2_dot_auth_dot_auth__pb2._PERMISSION
_BRANCHINFO.fields_by_name['branch'].message_type = _BRANCH
_BRANCHINFO.fields_by_name['head'].message_type = _COMMIT
_BRANCHINFO.fields_by_name['provenance'].message_type = _BRANCH
_BRANCHINFO.fields_by_name['subvenance'].message_type = _BRANCH
_BRANCHINFO.fields_by_name['direct_provenance'].message_type = _BRANCH
_BRANCHINFO.fields_by_name['trigger'].message_type = _TRIGGER
_COMMITORIGIN.fields_by_name['kind'].enum_type = _ORIGINKIND
_COMMIT.fields_by_name['branch'].message_type = _BRANCH
_COMMITINFO_DETAILS.containing_type = _COMMITINFO
_COMMITINFO.fields_by_name['commit'].message_type = _COMMIT
_COMMITINFO.fields_by_name['origin'].message_type = _COMMITORIGIN
_COMMITINFO.fields_by_name['parent_commit'].message_type = _COMMIT
_COMMITINFO.fields_by_name['child_commits'].message_type = _COMMIT
_COMMITINFO.fields_by_name['started'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_COMMITINFO.fields_by_name['finishing'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_COMMITINFO.fields_by_name['finished'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_COMMITINFO.fields_by_name['direct_provenance'].message_type = _BRANCH
_COMMITINFO.fields_by_name['details'].message_type = _COMMITINFO_DETAILS
_COMMITSETINFO.fields_by_name['commit_set'].message_type = _COMMITSET
_COMMITSETINFO.fields_by_name['commits'].message_type = _COMMITINFO
_FILEINFO.fields_by_name['file'].message_type = _FILE
_FILEINFO.fields_by_name['file_type'].enum_type = _FILETYPE
_FILEINFO.fields_by_name['committed'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CREATEREPOREQUEST.fields_by_name['repo'].message_type = _REPO
_INSPECTREPOREQUEST.fields_by_name['repo'].message_type = _REPO
_DELETEREPOREQUEST.fields_by_name['repo'].message_type = _REPO
_STARTCOMMITREQUEST.fields_by_name['parent'].message_type = _COMMIT
_STARTCOMMITREQUEST.fields_by_name['branch'].message_type = _BRANCH
_FINISHCOMMITREQUEST.fields_by_name['commit'].message_type = _COMMIT
_INSPECTCOMMITREQUEST.fields_by_name['commit'].message_type = _COMMIT
_INSPECTCOMMITREQUEST.fields_by_name['wait'].enum_type = _COMMITSTATE
_LISTCOMMITREQUEST.fields_by_name['repo'].message_type = _REPO
_LISTCOMMITREQUEST.fields_by_name['from'].message_type = _COMMIT
_LISTCOMMITREQUEST.fields_by_name['to'].message_type = _COMMIT
_LISTCOMMITREQUEST.fields_by_name['origin_kind'].enum_type = _ORIGINKIND
_INSPECTCOMMITSETREQUEST.fields_by_name['commit_set'].message_type = _COMMITSET
_SQUASHCOMMITSETREQUEST.fields_by_name['commit_set'].message_type = _COMMITSET
_DROPCOMMITSETREQUEST.fields_by_name['commit_set'].message_type = _COMMITSET
_SUBSCRIBECOMMITREQUEST.fields_by_name['repo'].message_type = _REPO
_SUBSCRIBECOMMITREQUEST.fields_by_name['from'].message_type = _COMMIT
_SUBSCRIBECOMMITREQUEST.fields_by_name['state'].enum_type = _COMMITSTATE
_SUBSCRIBECOMMITREQUEST.fields_by_name['origin_kind'].enum_type = _ORIGINKIND
_CLEARCOMMITREQUEST.fields_by_name['commit'].message_type = _COMMIT
_CREATEBRANCHREQUEST.fields_by_name['head'].message_type = _COMMIT
_CREATEBRANCHREQUEST.fields_by_name['branch'].message_type = _BRANCH
_CREATEBRANCHREQUEST.fields_by_name['provenance'].message_type = _BRANCH
_CREATEBRANCHREQUEST.fields_by_name['trigger'].message_type = _TRIGGER
_INSPECTBRANCHREQUEST.fields_by_name['branch'].message_type = _BRANCH
_LISTBRANCHREQUEST.fields_by_name['repo'].message_type = _REPO
_DELETEBRANCHREQUEST.fields_by_name['branch'].message_type = _BRANCH
_ADDFILE_URLSOURCE.containing_type = _ADDFILE
_ADDFILE.fields_by_name['raw'].message_type = google_dot_protobuf_dot_wrappers__pb2._BYTESVALUE
_ADDFILE.fields_by_name['url'].message_type = _ADDFILE_URLSOURCE
_ADDFILE.oneofs_by_name['source'].fields.append(
  _ADDFILE.fields_by_name['raw'])
_ADDFILE.fields_by_name['raw'].containing_oneof = _ADDFILE.oneofs_by_name['source']
_ADDFILE.oneofs_by_name['source'].fields.append(
  _ADDFILE.fields_by_name['url'])
_ADDFILE.fields_by_name['url'].containing_oneof = _ADDFILE.oneofs_by_name['source']
_COPYFILE.fields_by_name['src'].message_type = _FILE
_MODIFYFILEREQUEST.fields_by_name['set_commit'].message_type = _COMMIT
_MODIFYFILEREQUEST.fields_by_name['add_file'].message_type = _ADDFILE
_MODIFYFILEREQUEST.fields_by_name['delete_file'].message_type = _DELETEFILE
_MODIFYFILEREQUEST.fields_by_name['copy_file'].message_type = _COPYFILE
_MODIFYFILEREQUEST.oneofs_by_name['body'].fields.append(
  _MODIFYFILEREQUEST.fields_by_name['set_commit'])
_MODIFYFILEREQUEST.fields_by_name['set_commit'].containing_oneof = _MODIFYFILEREQUEST.oneofs_by_name['body']
_MODIFYFILEREQUEST.oneofs_by_name['body'].fields.append(
  _MODIFYFILEREQUEST.fields_by_name['add_file'])
_MODIFYFILEREQUEST.fields_by_name['add_file'].containing_oneof = _MODIFYFILEREQUEST.oneofs_by_name['body']
_MODIFYFILEREQUEST.oneofs_by_name['body'].fields.append(
  _MODIFYFILEREQUEST.fields_by_name['delete_file'])
_MODIFYFILEREQUEST.fields_by_name['delete_file'].containing_oneof = _MODIFYFILEREQUEST.oneofs_by_name['body']
_MODIFYFILEREQUEST.oneofs_by_name['body'].fields.append(
  _MODIFYFILEREQUEST.fields_by_name['copy_file'])
_MODIFYFILEREQUEST.fields_by_name['copy_file'].containing_oneof = _MODIFYFILEREQUEST.oneofs_by_name['body']
_GETFILEREQUEST.fields_by_name['file'].message_type = _FILE
_INSPECTFILEREQUEST.fields_by_name['file'].message_type = _FILE
_LISTFILEREQUEST.fields_by_name['file'].message_type = _FILE
_WALKFILEREQUEST.fields_by_name['file'].message_type = _FILE
_GLOBFILEREQUEST.fields_by_name['commit'].message_type = _COMMIT
_DIFFFILEREQUEST.fields_by_name['new_file'].message_type = _FILE
_DIFFFILEREQUEST.fields_by_name['old_file'].message_type = _FILE
_DIFFFILERESPONSE.fields_by_name['new_file'].message_type = _FILEINFO
_DIFFFILERESPONSE.fields_by_name['old_file'].message_type = _FILEINFO
_GETFILESETREQUEST.fields_by_name['commit'].message_type = _COMMIT
_ADDFILESETREQUEST.fields_by_name['commit'].message_type = _COMMIT
_RUNLOADTESTREQUEST.fields_by_name['branch'].message_type = _BRANCH
_RUNLOADTESTRESPONSE.fields_by_name['branch'].message_type = _BRANCH
DESCRIPTOR.message_types_by_name['Repo'] = _REPO
DESCRIPTOR.message_types_by_name['Branch'] = _BRANCH
DESCRIPTOR.message_types_by_name['File'] = _FILE
DESCRIPTOR.message_types_by_name['RepoInfo'] = _REPOINFO
DESCRIPTOR.message_types_by_name['RepoAuthInfo'] = _REPOAUTHINFO
DESCRIPTOR.message_types_by_name['BranchInfo'] = _BRANCHINFO
DESCRIPTOR.message_types_by_name['Trigger'] = _TRIGGER
DESCRIPTOR.message_types_by_name['CommitOrigin'] = _COMMITORIGIN
DESCRIPTOR.message_types_by_name['Commit'] = _COMMIT
DESCRIPTOR.message_types_by_name['CommitInfo'] = _COMMITINFO
DESCRIPTOR.message_types_by_name['CommitSet'] = _COMMITSET
DESCRIPTOR.message_types_by_name['CommitSetInfo'] = _COMMITSETINFO
DESCRIPTOR.message_types_by_name['FileInfo'] = _FILEINFO
DESCRIPTOR.message_types_by_name['CreateRepoRequest'] = _CREATEREPOREQUEST
DESCRIPTOR.message_types_by_name['InspectRepoRequest'] = _INSPECTREPOREQUEST
DESCRIPTOR.message_types_by_name['ListRepoRequest'] = _LISTREPOREQUEST
DESCRIPTOR.message_types_by_name['DeleteRepoRequest'] = _DELETEREPOREQUEST
DESCRIPTOR.message_types_by_name['StartCommitRequest'] = _STARTCOMMITREQUEST
DESCRIPTOR.message_types_by_name['FinishCommitRequest'] = _FINISHCOMMITREQUEST
DESCRIPTOR.message_types_by_name['InspectCommitRequest'] = _INSPECTCOMMITREQUEST
DESCRIPTOR.message_types_by_name['ListCommitRequest'] = _LISTCOMMITREQUEST
DESCRIPTOR.message_types_by_name['InspectCommitSetRequest'] = _INSPECTCOMMITSETREQUEST
DESCRIPTOR.message_types_by_name['ListCommitSetRequest'] = _LISTCOMMITSETREQUEST
DESCRIPTOR.message_types_by_name['SquashCommitSetRequest'] = _SQUASHCOMMITSETREQUEST
DESCRIPTOR.message_types_by_name['DropCommitSetRequest'] = _DROPCOMMITSETREQUEST
DESCRIPTOR.message_types_by_name['SubscribeCommitRequest'] = _SUBSCRIBECOMMITREQUEST
DESCRIPTOR.message_types_by_name['ClearCommitRequest'] = _CLEARCOMMITREQUEST
DESCRIPTOR.message_types_by_name['CreateBranchRequest'] = _CREATEBRANCHREQUEST
DESCRIPTOR.message_types_by_name['InspectBranchRequest'] = _INSPECTBRANCHREQUEST
DESCRIPTOR.message_types_by_name['ListBranchRequest'] = _LISTBRANCHREQUEST
DESCRIPTOR.message_types_by_name['DeleteBranchRequest'] = _DELETEBRANCHREQUEST
DESCRIPTOR.message_types_by_name['AddFile'] = _ADDFILE
DESCRIPTOR.message_types_by_name['DeleteFile'] = _DELETEFILE
DESCRIPTOR.message_types_by_name['CopyFile'] = _COPYFILE
DESCRIPTOR.message_types_by_name['ModifyFileRequest'] = _MODIFYFILEREQUEST
DESCRIPTOR.message_types_by_name['GetFileRequest'] = _GETFILEREQUEST
DESCRIPTOR.message_types_by_name['InspectFileRequest'] = _INSPECTFILEREQUEST
DESCRIPTOR.message_types_by_name['ListFileRequest'] = _LISTFILEREQUEST
DESCRIPTOR.message_types_by_name['WalkFileRequest'] = _WALKFILEREQUEST
DESCRIPTOR.message_types_by_name['GlobFileRequest'] = _GLOBFILEREQUEST
DESCRIPTOR.message_types_by_name['DiffFileRequest'] = _DIFFFILEREQUEST
DESCRIPTOR.message_types_by_name['DiffFileResponse'] = _DIFFFILERESPONSE
DESCRIPTOR.message_types_by_name['FsckRequest'] = _FSCKREQUEST
DESCRIPTOR.message_types_by_name['FsckResponse'] = _FSCKRESPONSE
DESCRIPTOR.message_types_by_name['CreateFileSetResponse'] = _CREATEFILESETRESPONSE
DESCRIPTOR.message_types_by_name['GetFileSetRequest'] = _GETFILESETREQUEST
DESCRIPTOR.message_types_by_name['AddFileSetRequest'] = _ADDFILESETREQUEST
DESCRIPTOR.message_types_by_name['RenewFileSetRequest'] = _RENEWFILESETREQUEST
DESCRIPTOR.message_types_by_name['ActivateAuthRequest'] = _ACTIVATEAUTHREQUEST
DESCRIPTOR.message_types_by_name['ActivateAuthResponse'] = _ACTIVATEAUTHRESPONSE
DESCRIPTOR.message_types_by_name['RunLoadTestRequest'] = _RUNLOADTESTREQUEST
DESCRIPTOR.message_types_by_name['RunLoadTestResponse'] = _RUNLOADTESTRESPONSE
DESCRIPTOR.enum_types_by_name['OriginKind'] = _ORIGINKIND
DESCRIPTOR.enum_types_by_name['FileType'] = _FILETYPE
DESCRIPTOR.enum_types_by_name['CommitState'] = _COMMITSTATE
DESCRIPTOR.enum_types_by_name['Delimiter'] = _DELIMITER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Repo = _reflection.GeneratedProtocolMessageType('Repo', (_message.Message,), {
  'DESCRIPTOR' : _REPO,
  '__module__' : 'python_pachyderm.proto.v2.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs_v2.Repo)
  })
_sym_db.RegisterMessage(Repo)

Branch = _reflection.GeneratedProtocolMessageType('Branch', (_message.Message,), {
  'DESCRIPTOR' : _BRANCH,
  '__module__' : 'python_pachyderm.proto.v2.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs_v2.Branch)
  })
_sym_db.RegisterMessage(Branch)

File = _reflection.GeneratedProtocolMessageType('File', (_message.Message,), {
  'DESCRIPTOR' : _FILE,
  '__module__' : 'python_pachyderm.proto.v2.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs_v2.File)
  })
_sym_db.RegisterMessage(File)

RepoInfo = _reflection.GeneratedProtocolMessageType('RepoInfo', (_message.Message,), {

  'Details' : _reflection.GeneratedProtocolMessageType('Details', (_message.Message,), {
    'DESCRIPTOR' : _REPOINFO_DETAILS,
    '__module__' : 'python_pachyderm.proto.v2.pfs.pfs_pb2'
    # @@protoc_insertion_point(class_scope:pfs_v2.RepoInfo.Details)
    })
  ,
  'DESCRIPTOR' : _REPOINFO,
  '__module__' : 'python_pachyderm.proto.v2.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs_v2.RepoInfo)
  })
_sym_db.RegisterMessage(RepoInfo)
_sym_db.RegisterMessage(RepoInfo.Details)

RepoAuthInfo = _reflection.GeneratedProtocolMessageType('RepoAuthInfo', (_message.Message,), {
  'DESCRIPTOR' : _REPOAUTHINFO,
  '__module__' : 'python_pachyderm.proto.v2.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs_v2.RepoAuthInfo)
  })
_sym_db.RegisterMessage(RepoAuthInfo)

BranchInfo = _reflection.GeneratedProtocolMessageType('BranchInfo', (_message.Message,), {
  'DESCRIPTOR' : _BRANCHINFO,
  '__module__' : 'python_pachyderm.proto.v2.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs_v2.BranchInfo)
  })
_sym_db.RegisterMessage(BranchInfo)

Trigger = _reflection.GeneratedProtocolMessageType('Trigger', (_message.Message,), {
  'DESCRIPTOR' : _TRIGGER,
  '__module__' : 'python_pachyderm.proto.v2.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs_v2.Trigger)
  })
_sym_db.RegisterMessage(Trigger)

CommitOrigin = _reflection.GeneratedProtocolMessageType('CommitOrigin', (_message.Message,), {
  'DESCRIPTOR' : _COMMITORIGIN,
  '__module__' : 'python_pachyderm.proto.v2.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs_v2.CommitOrigin)
  })
_sym_db.RegisterMessage(CommitOrigin)

Commit = _reflection.GeneratedProtocolMessageType('Commit', (_message.Message,), {
  'DESCRIPTOR' : _COMMIT,
  '__module__' : 'python_pachyderm.proto.v2.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs_v2.Commit)
  })
_sym_db.RegisterMessage(Commit)

CommitInfo = _reflection.GeneratedProtocolMessageType('CommitInfo', (_message.Message,), {

  'Details' : _reflection.GeneratedProtocolMessageType('Details', (_message.Message,), {
    'DESCRIPTOR' : _COMMITINFO_DETAILS,
    '__module__' : 'python_pachyderm.proto.v2.pfs.pfs_pb2'
    # @@protoc_insertion_point(class_scope:pfs_v2.CommitInfo.Details)
    })
  ,
  'DESCRIPTOR' : _COMMITINFO,
  '__module__' : 'python_pachyderm.proto.v2.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs_v2.CommitInfo)
  })
_sym_db.RegisterMessage(CommitInfo)
_sym_db.RegisterMessage(CommitInfo.Details)

CommitSet = _reflection.GeneratedProtocolMessageType('CommitSet', (_message.Message,), {
  'DESCRIPTOR' : _COMMITSET,
  '__module__' : 'python_pachyderm.proto.v2.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs_v2.CommitSet)
  })
_sym_db.RegisterMessage(CommitSet)

CommitSetInfo = _reflection.GeneratedProtocolMessageType('CommitSetInfo', (_message.Message,), {
  'DESCRIPTOR' : _COMMITSETINFO,
  '__module__' : 'python_pachyderm.proto.v2.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs_v2.CommitSetInfo)
  })
_sym_db.RegisterMessage(CommitSetInfo)

FileInfo = _reflection.GeneratedProtocolMessageType('FileInfo', (_message.Message,), {
  'DESCRIPTOR' : _FILEINFO,
  '__module__' : 'python_pachyderm.proto.v2.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs_v2.FileInfo)
  })
_sym_db.RegisterMessage(FileInfo)

CreateRepoRequest = _reflection.GeneratedProtocolMessageType('CreateRepoRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEREPOREQUEST,
  '__module__' : 'python_pachyderm.proto.v2.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs_v2.CreateRepoRequest)
  })
_sym_db.RegisterMessage(CreateRepoRequest)

InspectRepoRequest = _reflection.GeneratedProtocolMessageType('InspectRepoRequest', (_message.Message,), {
  'DESCRIPTOR' : _INSPECTREPOREQUEST,
  '__module__' : 'python_pachyderm.proto.v2.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs_v2.InspectRepoRequest)
  })
_sym_db.RegisterMessage(InspectRepoRequest)

ListRepoRequest = _reflection.GeneratedProtocolMessageType('ListRepoRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTREPOREQUEST,
  '__module__' : 'python_pachyderm.proto.v2.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs_v2.ListRepoRequest)
  })
_sym_db.RegisterMessage(ListRepoRequest)

DeleteRepoRequest = _reflection.GeneratedProtocolMessageType('DeleteRepoRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEREPOREQUEST,
  '__module__' : 'python_pachyderm.proto.v2.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs_v2.DeleteRepoRequest)
  })
_sym_db.RegisterMessage(DeleteRepoRequest)

StartCommitRequest = _reflection.GeneratedProtocolMessageType('StartCommitRequest', (_message.Message,), {
  'DESCRIPTOR' : _STARTCOMMITREQUEST,
  '__module__' : 'python_pachyderm.proto.v2.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs_v2.StartCommitRequest)
  })
_sym_db.RegisterMessage(StartCommitRequest)

FinishCommitRequest = _reflection.GeneratedProtocolMessageType('FinishCommitRequest', (_message.Message,), {
  'DESCRIPTOR' : _FINISHCOMMITREQUEST,
  '__module__' : 'python_pachyderm.proto.v2.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs_v2.FinishCommitRequest)
  })
_sym_db.RegisterMessage(FinishCommitRequest)

InspectCommitRequest = _reflection.GeneratedProtocolMessageType('InspectCommitRequest', (_message.Message,), {
  'DESCRIPTOR' : _INSPECTCOMMITREQUEST,
  '__module__' : 'python_pachyderm.proto.v2.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs_v2.InspectCommitRequest)
  })
_sym_db.RegisterMessage(InspectCommitRequest)

ListCommitRequest = _reflection.GeneratedProtocolMessageType('ListCommitRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTCOMMITREQUEST,
  '__module__' : 'python_pachyderm.proto.v2.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs_v2.ListCommitRequest)
  })
_sym_db.RegisterMessage(ListCommitRequest)

InspectCommitSetRequest = _reflection.GeneratedProtocolMessageType('InspectCommitSetRequest', (_message.Message,), {
  'DESCRIPTOR' : _INSPECTCOMMITSETREQUEST,
  '__module__' : 'python_pachyderm.proto.v2.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs_v2.InspectCommitSetRequest)
  })
_sym_db.RegisterMessage(InspectCommitSetRequest)

ListCommitSetRequest = _reflection.GeneratedProtocolMessageType('ListCommitSetRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTCOMMITSETREQUEST,
  '__module__' : 'python_pachyderm.proto.v2.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs_v2.ListCommitSetRequest)
  })
_sym_db.RegisterMessage(ListCommitSetRequest)

SquashCommitSetRequest = _reflection.GeneratedProtocolMessageType('SquashCommitSetRequest', (_message.Message,), {
  'DESCRIPTOR' : _SQUASHCOMMITSETREQUEST,
  '__module__' : 'python_pachyderm.proto.v2.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs_v2.SquashCommitSetRequest)
  })
_sym_db.RegisterMessage(SquashCommitSetRequest)

DropCommitSetRequest = _reflection.GeneratedProtocolMessageType('DropCommitSetRequest', (_message.Message,), {
  'DESCRIPTOR' : _DROPCOMMITSETREQUEST,
  '__module__' : 'python_pachyderm.proto.v2.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs_v2.DropCommitSetRequest)
  })
_sym_db.RegisterMessage(DropCommitSetRequest)

SubscribeCommitRequest = _reflection.GeneratedProtocolMessageType('SubscribeCommitRequest', (_message.Message,), {
  'DESCRIPTOR' : _SUBSCRIBECOMMITREQUEST,
  '__module__' : 'python_pachyderm.proto.v2.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs_v2.SubscribeCommitRequest)
  })
_sym_db.RegisterMessage(SubscribeCommitRequest)

ClearCommitRequest = _reflection.GeneratedProtocolMessageType('ClearCommitRequest', (_message.Message,), {
  'DESCRIPTOR' : _CLEARCOMMITREQUEST,
  '__module__' : 'python_pachyderm.proto.v2.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs_v2.ClearCommitRequest)
  })
_sym_db.RegisterMessage(ClearCommitRequest)

CreateBranchRequest = _reflection.GeneratedProtocolMessageType('CreateBranchRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEBRANCHREQUEST,
  '__module__' : 'python_pachyderm.proto.v2.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs_v2.CreateBranchRequest)
  })
_sym_db.RegisterMessage(CreateBranchRequest)

InspectBranchRequest = _reflection.GeneratedProtocolMessageType('InspectBranchRequest', (_message.Message,), {
  'DESCRIPTOR' : _INSPECTBRANCHREQUEST,
  '__module__' : 'python_pachyderm.proto.v2.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs_v2.InspectBranchRequest)
  })
_sym_db.RegisterMessage(InspectBranchRequest)

ListBranchRequest = _reflection.GeneratedProtocolMessageType('ListBranchRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTBRANCHREQUEST,
  '__module__' : 'python_pachyderm.proto.v2.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs_v2.ListBranchRequest)
  })
_sym_db.RegisterMessage(ListBranchRequest)

DeleteBranchRequest = _reflection.GeneratedProtocolMessageType('DeleteBranchRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEBRANCHREQUEST,
  '__module__' : 'python_pachyderm.proto.v2.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs_v2.DeleteBranchRequest)
  })
_sym_db.RegisterMessage(DeleteBranchRequest)

AddFile = _reflection.GeneratedProtocolMessageType('AddFile', (_message.Message,), {

  'URLSource' : _reflection.GeneratedProtocolMessageType('URLSource', (_message.Message,), {
    'DESCRIPTOR' : _ADDFILE_URLSOURCE,
    '__module__' : 'python_pachyderm.proto.v2.pfs.pfs_pb2'
    # @@protoc_insertion_point(class_scope:pfs_v2.AddFile.URLSource)
    })
  ,
  'DESCRIPTOR' : _ADDFILE,
  '__module__' : 'python_pachyderm.proto.v2.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs_v2.AddFile)
  })
_sym_db.RegisterMessage(AddFile)
_sym_db.RegisterMessage(AddFile.URLSource)

DeleteFile = _reflection.GeneratedProtocolMessageType('DeleteFile', (_message.Message,), {
  'DESCRIPTOR' : _DELETEFILE,
  '__module__' : 'python_pachyderm.proto.v2.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs_v2.DeleteFile)
  })
_sym_db.RegisterMessage(DeleteFile)

CopyFile = _reflection.GeneratedProtocolMessageType('CopyFile', (_message.Message,), {
  'DESCRIPTOR' : _COPYFILE,
  '__module__' : 'python_pachyderm.proto.v2.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs_v2.CopyFile)
  })
_sym_db.RegisterMessage(CopyFile)

ModifyFileRequest = _reflection.GeneratedProtocolMessageType('ModifyFileRequest', (_message.Message,), {
  'DESCRIPTOR' : _MODIFYFILEREQUEST,
  '__module__' : 'python_pachyderm.proto.v2.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs_v2.ModifyFileRequest)
  })
_sym_db.RegisterMessage(ModifyFileRequest)

GetFileRequest = _reflection.GeneratedProtocolMessageType('GetFileRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFILEREQUEST,
  '__module__' : 'python_pachyderm.proto.v2.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs_v2.GetFileRequest)
  })
_sym_db.RegisterMessage(GetFileRequest)

InspectFileRequest = _reflection.GeneratedProtocolMessageType('InspectFileRequest', (_message.Message,), {
  'DESCRIPTOR' : _INSPECTFILEREQUEST,
  '__module__' : 'python_pachyderm.proto.v2.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs_v2.InspectFileRequest)
  })
_sym_db.RegisterMessage(InspectFileRequest)

ListFileRequest = _reflection.GeneratedProtocolMessageType('ListFileRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTFILEREQUEST,
  '__module__' : 'python_pachyderm.proto.v2.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs_v2.ListFileRequest)
  })
_sym_db.RegisterMessage(ListFileRequest)

WalkFileRequest = _reflection.GeneratedProtocolMessageType('WalkFileRequest', (_message.Message,), {
  'DESCRIPTOR' : _WALKFILEREQUEST,
  '__module__' : 'python_pachyderm.proto.v2.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs_v2.WalkFileRequest)
  })
_sym_db.RegisterMessage(WalkFileRequest)

GlobFileRequest = _reflection.GeneratedProtocolMessageType('GlobFileRequest', (_message.Message,), {
  'DESCRIPTOR' : _GLOBFILEREQUEST,
  '__module__' : 'python_pachyderm.proto.v2.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs_v2.GlobFileRequest)
  })
_sym_db.RegisterMessage(GlobFileRequest)

DiffFileRequest = _reflection.GeneratedProtocolMessageType('DiffFileRequest', (_message.Message,), {
  'DESCRIPTOR' : _DIFFFILEREQUEST,
  '__module__' : 'python_pachyderm.proto.v2.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs_v2.DiffFileRequest)
  })
_sym_db.RegisterMessage(DiffFileRequest)

DiffFileResponse = _reflection.GeneratedProtocolMessageType('DiffFileResponse', (_message.Message,), {
  'DESCRIPTOR' : _DIFFFILERESPONSE,
  '__module__' : 'python_pachyderm.proto.v2.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs_v2.DiffFileResponse)
  })
_sym_db.RegisterMessage(DiffFileResponse)

FsckRequest = _reflection.GeneratedProtocolMessageType('FsckRequest', (_message.Message,), {
  'DESCRIPTOR' : _FSCKREQUEST,
  '__module__' : 'python_pachyderm.proto.v2.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs_v2.FsckRequest)
  })
_sym_db.RegisterMessage(FsckRequest)

FsckResponse = _reflection.GeneratedProtocolMessageType('FsckResponse', (_message.Message,), {
  'DESCRIPTOR' : _FSCKRESPONSE,
  '__module__' : 'python_pachyderm.proto.v2.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs_v2.FsckResponse)
  })
_sym_db.RegisterMessage(FsckResponse)

CreateFileSetResponse = _reflection.GeneratedProtocolMessageType('CreateFileSetResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEFILESETRESPONSE,
  '__module__' : 'python_pachyderm.proto.v2.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs_v2.CreateFileSetResponse)
  })
_sym_db.RegisterMessage(CreateFileSetResponse)

GetFileSetRequest = _reflection.GeneratedProtocolMessageType('GetFileSetRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFILESETREQUEST,
  '__module__' : 'python_pachyderm.proto.v2.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs_v2.GetFileSetRequest)
  })
_sym_db.RegisterMessage(GetFileSetRequest)

AddFileSetRequest = _reflection.GeneratedProtocolMessageType('AddFileSetRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDFILESETREQUEST,
  '__module__' : 'python_pachyderm.proto.v2.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs_v2.AddFileSetRequest)
  })
_sym_db.RegisterMessage(AddFileSetRequest)

RenewFileSetRequest = _reflection.GeneratedProtocolMessageType('RenewFileSetRequest', (_message.Message,), {
  'DESCRIPTOR' : _RENEWFILESETREQUEST,
  '__module__' : 'python_pachyderm.proto.v2.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs_v2.RenewFileSetRequest)
  })
_sym_db.RegisterMessage(RenewFileSetRequest)

ActivateAuthRequest = _reflection.GeneratedProtocolMessageType('ActivateAuthRequest', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVATEAUTHREQUEST,
  '__module__' : 'python_pachyderm.proto.v2.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs_v2.ActivateAuthRequest)
  })
_sym_db.RegisterMessage(ActivateAuthRequest)

ActivateAuthResponse = _reflection.GeneratedProtocolMessageType('ActivateAuthResponse', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVATEAUTHRESPONSE,
  '__module__' : 'python_pachyderm.proto.v2.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs_v2.ActivateAuthResponse)
  })
_sym_db.RegisterMessage(ActivateAuthResponse)

RunLoadTestRequest = _reflection.GeneratedProtocolMessageType('RunLoadTestRequest', (_message.Message,), {
  'DESCRIPTOR' : _RUNLOADTESTREQUEST,
  '__module__' : 'python_pachyderm.proto.v2.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs_v2.RunLoadTestRequest)
  })
_sym_db.RegisterMessage(RunLoadTestRequest)

RunLoadTestResponse = _reflection.GeneratedProtocolMessageType('RunLoadTestResponse', (_message.Message,), {
  'DESCRIPTOR' : _RUNLOADTESTRESPONSE,
  '__module__' : 'python_pachyderm.proto.v2.pfs.pfs_pb2'
  # @@protoc_insertion_point(class_scope:pfs_v2.RunLoadTestResponse)
  })
_sym_db.RegisterMessage(RunLoadTestResponse)


DESCRIPTOR._options = None

_API = _descriptor.ServiceDescriptor(
  name='API',
  full_name='pfs_v2.API',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=5281,
  serialized_end=7681,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateRepo',
    full_name='pfs_v2.API.CreateRepo',
    index=0,
    containing_service=None,
    input_type=_CREATEREPOREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='InspectRepo',
    full_name='pfs_v2.API.InspectRepo',
    index=1,
    containing_service=None,
    input_type=_INSPECTREPOREQUEST,
    output_type=_REPOINFO,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListRepo',
    full_name='pfs_v2.API.ListRepo',
    index=2,
    containing_service=None,
    input_type=_LISTREPOREQUEST,
    output_type=_REPOINFO,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteRepo',
    full_name='pfs_v2.API.DeleteRepo',
    index=3,
    containing_service=None,
    input_type=_DELETEREPOREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StartCommit',
    full_name='pfs_v2.API.StartCommit',
    index=4,
    containing_service=None,
    input_type=_STARTCOMMITREQUEST,
    output_type=_COMMIT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FinishCommit',
    full_name='pfs_v2.API.FinishCommit',
    index=5,
    containing_service=None,
    input_type=_FINISHCOMMITREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ClearCommit',
    full_name='pfs_v2.API.ClearCommit',
    index=6,
    containing_service=None,
    input_type=_CLEARCOMMITREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='InspectCommit',
    full_name='pfs_v2.API.InspectCommit',
    index=7,
    containing_service=None,
    input_type=_INSPECTCOMMITREQUEST,
    output_type=_COMMITINFO,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListCommit',
    full_name='pfs_v2.API.ListCommit',
    index=8,
    containing_service=None,
    input_type=_LISTCOMMITREQUEST,
    output_type=_COMMITINFO,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SubscribeCommit',
    full_name='pfs_v2.API.SubscribeCommit',
    index=9,
    containing_service=None,
    input_type=_SUBSCRIBECOMMITREQUEST,
    output_type=_COMMITINFO,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='InspectCommitSet',
    full_name='pfs_v2.API.InspectCommitSet',
    index=10,
    containing_service=None,
    input_type=_INSPECTCOMMITSETREQUEST,
    output_type=_COMMITINFO,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListCommitSet',
    full_name='pfs_v2.API.ListCommitSet',
    index=11,
    containing_service=None,
    input_type=_LISTCOMMITSETREQUEST,
    output_type=_COMMITSETINFO,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SquashCommitSet',
    full_name='pfs_v2.API.SquashCommitSet',
    index=12,
    containing_service=None,
    input_type=_SQUASHCOMMITSETREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DropCommitSet',
    full_name='pfs_v2.API.DropCommitSet',
    index=13,
    containing_service=None,
    input_type=_DROPCOMMITSETREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateBranch',
    full_name='pfs_v2.API.CreateBranch',
    index=14,
    containing_service=None,
    input_type=_CREATEBRANCHREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='InspectBranch',
    full_name='pfs_v2.API.InspectBranch',
    index=15,
    containing_service=None,
    input_type=_INSPECTBRANCHREQUEST,
    output_type=_BRANCHINFO,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListBranch',
    full_name='pfs_v2.API.ListBranch',
    index=16,
    containing_service=None,
    input_type=_LISTBRANCHREQUEST,
    output_type=_BRANCHINFO,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteBranch',
    full_name='pfs_v2.API.DeleteBranch',
    index=17,
    containing_service=None,
    input_type=_DELETEBRANCHREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ModifyFile',
    full_name='pfs_v2.API.ModifyFile',
    index=18,
    containing_service=None,
    input_type=_MODIFYFILEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetFile',
    full_name='pfs_v2.API.GetFile',
    index=19,
    containing_service=None,
    input_type=_GETFILEREQUEST,
    output_type=google_dot_protobuf_dot_wrappers__pb2._BYTESVALUE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetFileTAR',
    full_name='pfs_v2.API.GetFileTAR',
    index=20,
    containing_service=None,
    input_type=_GETFILEREQUEST,
    output_type=google_dot_protobuf_dot_wrappers__pb2._BYTESVALUE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='InspectFile',
    full_name='pfs_v2.API.InspectFile',
    index=21,
    containing_service=None,
    input_type=_INSPECTFILEREQUEST,
    output_type=_FILEINFO,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListFile',
    full_name='pfs_v2.API.ListFile',
    index=22,
    containing_service=None,
    input_type=_LISTFILEREQUEST,
    output_type=_FILEINFO,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='WalkFile',
    full_name='pfs_v2.API.WalkFile',
    index=23,
    containing_service=None,
    input_type=_WALKFILEREQUEST,
    output_type=_FILEINFO,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GlobFile',
    full_name='pfs_v2.API.GlobFile',
    index=24,
    containing_service=None,
    input_type=_GLOBFILEREQUEST,
    output_type=_FILEINFO,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DiffFile',
    full_name='pfs_v2.API.DiffFile',
    index=25,
    containing_service=None,
    input_type=_DIFFFILEREQUEST,
    output_type=_DIFFFILERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ActivateAuth',
    full_name='pfs_v2.API.ActivateAuth',
    index=26,
    containing_service=None,
    input_type=_ACTIVATEAUTHREQUEST,
    output_type=_ACTIVATEAUTHRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteAll',
    full_name='pfs_v2.API.DeleteAll',
    index=27,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Fsck',
    full_name='pfs_v2.API.Fsck',
    index=28,
    containing_service=None,
    input_type=_FSCKREQUEST,
    output_type=_FSCKRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateFileSet',
    full_name='pfs_v2.API.CreateFileSet',
    index=29,
    containing_service=None,
    input_type=_MODIFYFILEREQUEST,
    output_type=_CREATEFILESETRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetFileSet',
    full_name='pfs_v2.API.GetFileSet',
    index=30,
    containing_service=None,
    input_type=_GETFILESETREQUEST,
    output_type=_CREATEFILESETRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AddFileSet',
    full_name='pfs_v2.API.AddFileSet',
    index=31,
    containing_service=None,
    input_type=_ADDFILESETREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RenewFileSet',
    full_name='pfs_v2.API.RenewFileSet',
    index=32,
    containing_service=None,
    input_type=_RENEWFILESETREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RunLoadTest',
    full_name='pfs_v2.API.RunLoadTest',
    index=33,
    containing_service=None,
    input_type=_RUNLOADTESTREQUEST,
    output_type=_RUNLOADTESTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RunLoadTestDefault',
    full_name='pfs_v2.API.RunLoadTestDefault',
    index=34,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_RUNLOADTESTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_API)

DESCRIPTOR.services_by_name['API'] = _API

# @@protoc_insertion_point(module_scope)
